@@ -16,10 +16,10 @@ my $image = new Image::BoxModel (
 					#If you pass arguments directly from the command line be aware that there is no error-checking!
 );	
 
-print $image -> Annotate (text=> 'Hello @ Text-demo', padding_top=>10, padding_bottom=> 20, background => "white");
+print $image -> Annotate (text=> 'Hello @ Text-demo', padding_top=>10, padding_bottom=> 20, background => "white", font => './FreeSans.ttf');
 
 my $lowest = -4;
 my $highest = 10;
-print $image -> Annotate (text => "happiness (range from $lowest to $highest)", textsize => 14, box_position => "left", rotate=>-90, padding_right => "10", text_position => "Center");
+print $image -> Annotate (text => "happiness (range from $lowest to $highest)", textsize => 14, box_position => "left", rotate=>-90, padding_right => "10", text_position => "Center", font => './FreeSans.ttf');
 
 $image -> Save(file=> "10_text_demo_$image->{lib}.png");
\ No newline at end of file
